@@ -1,5 +1,5 @@
 // rak - Rakshasa's toolbox
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -46,10 +46,10 @@
 
 namespace rak {
 
-template <typename Value, typename Compare, typename Equal>
-class priority_queue : public std::vector<Value> {
+template <typename Value, typename Compare, typename Equal, typename Alloc = std::allocator<Value> >
+class priority_queue : public std::vector<Value, Alloc> {
 public:
-  typedef std::vector<Value>                  base_type;
+  typedef std::vector<Value, Alloc>           base_type;
   typedef typename base_type::reference       reference;
   typedef typename base_type::const_reference const_reference;
   typedef typename base_type::iterator        iterator;
@@ -60,6 +60,7 @@ public:
   using base_type::end;
   using base_type::size;
   using base_type::empty;
+  using base_type::clear;
 
   priority_queue(Compare l = Compare(), Equal e = Equal())
     : m_compare(l), m_equal(e) {}
