@@ -49,6 +49,7 @@ void initialize_command_file();
 void initialize_command_ip();
 void initialize_command_peer();
 void initialize_command_local();
+void initialize_command_logging();
 void initialize_command_network();
 void initialize_command_groups();
 void initialize_command_throttle();
@@ -63,6 +64,7 @@ initialize_commands() {
   initialize_command_network();
   initialize_command_groups();
   initialize_command_local();
+  initialize_command_logging();
   initialize_command_ui();
   initialize_command_download();
   initialize_command_file();
