@@ -68,6 +68,10 @@ namespace rpc {
   class object_storage;
 }
 
+namespace torrent {
+  class directory_events;
+}
+
 class Control {
 public:
   Control();
@@ -98,6 +102,8 @@ public:
   rpc::CommandScheduler* command_scheduler()        { return m_commandScheduler; }
   rpc::object_storage*   object_storage()           { return m_objectStorage; }
 
+  torrent::directory_events* directory_events()     { return m_directory_events; }
+
   uint64_t            tick() const                  { return m_tick; }
   void                inc_tick()                    { m_tick++; }
 
@@ -117,8 +123,9 @@ private:
   input::Manager*     m_input;
   input::InputEvent*  m_inputStdin;
 
-  rpc::CommandScheduler* m_commandScheduler;
-  rpc::object_storage*   m_objectStorage;
+  rpc::CommandScheduler*     m_commandScheduler;
+  rpc::object_storage*       m_objectStorage;
+  torrent::directory_events* m_directory_events;
 
   uint64_t            m_tick;
 
