@@ -44,7 +44,7 @@
 #include <iosfwd>
 #include <rak/priority_queue_default.h>
 #include <torrent/object.h>
-#include <tr1/functional>
+#include lt_tr1_functional
 
 #include "http_queue.h"
 
@@ -54,7 +54,7 @@ class Manager;
 
 class DownloadFactory {
 public:
-  typedef std::tr1::function<void ()> slot_void;
+  typedef std::function<void ()> slot_void;
   typedef std::vector<std::string> command_list_type;
 
   // Do not destroy this object while it is in a HttpQueue.
