@@ -50,7 +50,7 @@ namespace display {
 Manager::Manager() :
   m_forceRedraw(false) {
 
-  m_taskUpdate.slot() = std::tr1::bind(&Manager::receive_update, this);
+  m_taskUpdate.slot() = std::bind(&Manager::receive_update, this);
 }
 
 Manager::~Manager() {
