@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -66,8 +66,12 @@ char*       print_ddhhmm(char* first, char* last, time_t t);
 char*       print_ddmmyyyy(char* first, char* last, time_t t);
 
 char*       print_download_title(char* first, char* last, core::Download* d);
-char*       print_download_info(char* first, char* last, core::Download* d);
+char*       print_download_info_full(char* first, char* last, core::Download* d);
 char*       print_download_status(char* first, char* last, core::Download* d);
+
+char*       print_download_column_compact(char* first, char* last);
+char*       print_download_info_compact(char* first, char* last, core::Download* d);
+
 char*       print_download_time_left(char* first, char* last, core::Download* d);
 char*       print_download_percentage_done(char* first, char* last, core::Download* d);
 
