@@ -37,9 +37,7 @@
 #ifndef RTORRENT_DISPLAY_WINDOW_LOG_COMPLETE_H
 #define RTORRENT_DISPLAY_WINDOW_LOG_COMPLETE_H
 
-#include <sigc++/connection.h>
-
-#include "core/log.h"
+#include <torrent/utils/log_buffer.h>
 
 #include "window.h"
 
@@ -47,20 +45,17 @@ namespace display {
 
 class WindowLogComplete : public Window {
 public:
-  typedef core::Log::iterator iterator;
+  typedef torrent::log_buffer::const_iterator iterator;
 
-  WindowLogComplete(core::Log* l);
+  WindowLogComplete(torrent::log_buffer* l);
   ~WindowLogComplete();
 
   virtual void     redraw();
 
-  void             receive_update();
-
 private:
   inline iterator  find_older();
 
-  core::Log*       m_log;
-  sigc::connection m_connUpdate;
+  torrent::log_buffer* m_log;
 };
 
 }
