@@ -37,6 +37,8 @@
 #ifndef RTORRENT_UI_ELEMENT_PEER_LIST_H
 #define RTORRENT_UI_ELEMENT_PEER_LIST_H
 
+#include <torrent/peer/connection_list.h>
+
 #include "core/download.h"
 
 #include "element_base.h"
@@ -49,6 +51,8 @@ class ElementPeerList : public ElementBase {
 public:
   typedef std::list<torrent::Peer*> PList;
 
+  typedef torrent::ConnectionList::signal_peer_type::iterator signal_connection;
+
   typedef enum {
     DISPLAY_LIST,
     DISPLAY_INFO,
@@ -89,8 +93,8 @@ private:
   PList               m_list;
   PList::iterator     m_listItr;
 
-  sigc::connection    m_connPeerConnected;
-  sigc::connection    m_connPeerDisconnected;
+  signal_connection   m_peer_connected;
+  signal_connection   m_peer_disconnected;
 };
 
 }
