@@ -41,6 +41,7 @@
 #include <string>
 #include <algorithm>
 #include <functional>
+#include <torrent/utils/log.h>
 
 #include "element_base.h"
 
@@ -69,8 +70,14 @@ public:
     while (first != last)
       m_list.push_back(*(first++));
 
-    m_window->set_range(m_list.begin(), m_list.end());
-    m_window->mark_dirty();
+    if (m_window != NULL) {
+      lt_log_print(torrent::LOG_UI_EVENTS, "element_string_list: set range (visible)");
+
+      m_window->set_range(m_list.begin(), m_list.end());
+      m_window->mark_dirty();
+    } else {
+      lt_log_print(torrent::LOG_UI_EVENTS, "element_string_list: set range (hidden)");
+    }
   }
 
   // A hack, clean this up.
@@ -81,8 +88,14 @@ public:
     while (first != last)
       m_list.push_back((first++)->d_name);
 
-    m_window->set_range(m_list.begin(), m_list.end());
-    m_window->mark_dirty();
+    if (m_window != NULL) {
+      lt_log_print(torrent::LOG_UI_EVENTS, "element_string_list: set dirent range (visible)");
+
+      m_window->set_range(m_list.begin(), m_list.end());
+      m_window->mark_dirty();
+    } else {
+      lt_log_print(torrent::LOG_UI_EVENTS, "element_string_list: set dirent range (hidden)");
+    }
   }
 
   void                next_screen();
