@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ Lockfile::try_lock() {
 
   if (pos == 0) {
     ::snprintf(buf + std::strlen(buf), 255, ":+%i\n", ::getpid());
-    ::write(fd, buf, std::strlen(buf));
+    int __UNUSED result = ::write(fd, buf, std::strlen(buf));
   }
 
   ::close(fd);
